@@ -2,9 +2,9 @@
 .. module author:: Cuongitl
 """
 
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 from pyftx.timer import PerpetualTimer
 from pyftx.exceptions import FtxValueError, FtxAPIException, FtxWebsocketUnableToConnect
 from pyftx.authentication import signature, ws_signature
 from pyftx.client import Client, AsyncClient
-from pyftx.streams import ThreadedWebsocketManager
+from pyftx.streams import FtxSocketManager, ThreadedWebsocketManager
